package com.bipt.intelligentapplicationorchestrationservice.pojo;

import com.fasterxml.jackson.annotation.JsonView;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.datatype.jsr310.ser.LocalDateTimeSerializer;
import lombok.Data;

import java.time.LocalDateTime;

@Data
public class GpuResponseDTO {
    @JsonView
    private Long GPUId;
    private String GPUModel;
    private Integer GPUMemorySize;
    private String Ip;

    @JsonSerialize(using = LocalDateTimeSerializer.class)
    private LocalDateTime createTime;

    // Builder类
    public static class Builder {
        private Long id;
        private String model;
        private Integer memory;
        private String ip;
        private LocalDateTime createTime = LocalDateTime.now(); // 统一命名为createTime

        public Builder id(Long id) {
            this.id = id;
            return this;
        }

        public Builder model(String model) {
            this.model = model;
            return this;
        }

        public Builder memory(Integer memory) {
            this.memory = memory;
            return this;
        }

        public Builder ip(String ip) {
            this.ip = ip;
            return this;
        }

        public Builder createTime(LocalDateTime createTime) {
            this.createTime = createTime;
            return this;
        }

        public GpuResponseDTO build() {
            // 必填字段校验
            if (id == null) {
                throw new IllegalArgumentException("GPU ID必须填写");
            }

            GpuResponseDTO dto = new GpuResponseDTO();
            dto.setGPUId(id);
            dto.setGPUModel(model);
            dto.setGPUMemorySize(memory);
            dto.setIp(ip);
            dto.setCreateTime(createTime); // 正确赋值createTime

            return dto;
        }
    }

    public String getCreateTimeStr() {
        return "GPU创建时间：" + (createTime != null ? createTime.toString() : "未设置");
    }
}